==> opencc-doc-1.0.3-2-aarch64.pkg.tar.xz: usr/share/opencc/doc/html/search/all_d.js <==
var searchData=
[
  ['opencc_20c_20api',['OpenCC C API',['../group__opencc__c__api.html',1,'']]],
  ['opencc_5fclose',['opencc_close',['../group__opencc__c__api.html#gae4d995fd7bb65e2d4f386aa5cf0dbbb1',1,'opencc_close(opencc_t opencc):&#160;SimpleConverter.cpp'],['../group__opencc__c__api.html#gae4d995fd7bb65e2d4f386aa5cf0dbbb1',1,'opencc_close(opencc_t opencc):&#160;SimpleConverter.cpp']]],
  ['opencc_5fconvert_5futf8',['opencc_convert_utf8',['../group__opencc__c__api.html#gaedebe843f05973efd295461be90d50f2',1,'opencc_convert_utf8(opencc_t opencc, const char *input, size_t length):&#160;SimpleConverter.cpp'],['../group__opencc__c__api.html#gaedebe843f05973efd295461be90d50f2',1,'opencc_convert_utf8(opencc_t opencc, const char *input, size_t length):&#160;SimpleConverter.cpp']]],
  ['opencc_5fconvert_5futf8_5ffree',['opencc_convert_utf8_free',['../group__opencc__c__api.html#ga6c11f94e7bee16c080e6d8ab5c16ea84',1,'opencc_convert_utf8_free(char *str):&#160;SimpleConverter.cpp'],['../group__opencc__c__api.html#ga6c11f94e7bee16c080e6d8ab5c16ea84',1,'opencc_convert_utf8_free(char *str):&#160;SimpleConverter.cpp']]],
  ['opencc_5fconvert_5futf8_5fto_5fbuffer',['opencc_convert_utf8_to_buffer',['../group__opencc__c__api.html#ga9922ab17f25a2d93060292630eb46b81',1,'opencc_convert_utf8_to_buffer(opencc_t opencc, const char *input, size_t length, char *output):&#160;SimpleConverter.cpp'],['../group__opencc__c__api.html#ga9922ab17f25a2d93060292630eb46b81',1,'opencc_convert_utf8_to_buffer(opencc_t opencc, const char *input, size_t length, char *output):&#160;SimpleConverter.cpp']]],
  ['opencc_20c_2b_2b_20comprehensive_20api',['OpenCC C++ Comprehensive API',['../group__opencc__cpp__api.html',1,'']]],
  ['opencc_5fdefault_5fconfig_5fsimp_5fto_5ftrad',['OPENCC_DEFAULT_CONFIG_SIMP_TO_TRAD',['../group__opencc__c__api.html#ga05b32035094049395f8975f9d2ffa1a2',1,'opencc.h']]],
  ['opencc_5fdefault_5fconfig_5ftrad_5fto_5fsimp',['OPENCC_DEFAULT_CONFIG_TRAD_TO_SIMP',['../group__opencc__c__api.html#gaede2d75ff352d979e89dfc390aa855c8',1,'opencc.h']]],
  ['opencc_5ferror',['opencc_error',['../group__opencc__c__api.html#ga57698a98df649f5f3f4239419f0867bc',1,'opencc_error(void):&#160;SimpleConverter.cpp'],['../group__opencc__c__api.html#ga57698a98df649f5f3f4239419f0867bc',1,'opencc_error(void):&#160;SimpleConverter.cpp']]],
  ['opencc_5fopen',['opencc_open',['../group__opencc__c__api.html#ga3aa43bc27b880c05c14c15b2c8952336',1,'opencc_open(const char *configFileName):&#160;SimpleConverter.cpp'],['../group__opencc__c__api.html#ga3aa43bc27b880c05c14c15b2c8952336',1,'opencc_open(const char *configFileName):&#160;SimpleConverter.cpp']]],
  ['opencc_20c_2b_2b_20simple_20api',['OpenCC C++ Simple API',['../group__opencc__simple__api.html',1,'']]],
  ['opencc_5ft',['opencc_t',['../group__opencc__c__api.html#gaa08a1436fedc071dc6fc352c98a6ade9',1,'opencc.h']]],
  ['optional',['Optional',['../classopencc_1_1_optional.html',1,'opencc']]],
  ['optional',['Optional',['../classopencc_1_1_optional.html#afc26cd1d9152426778b6aa532adb10d9',1,'opencc::Optional']]],
  ['optional_3c_20t_20_2a_20_3e',['Optional&lt; T * &gt;',['../classopencc_1_1_optional_3_01_t_01_5_01_4.html',1,'opencc']]]
];

==> opencc-doc-1.0.5-2-aarch64.pkg.tar.xz: usr/share/opencc/doc/html/search/all_d.js <==
var searchData=
[
  ['open_20chinese_20convert_20開放中文轉換',['Open Chinese Convert 開放中文轉換',['../index.html',1,'']]],
  ['opencc_20c_20api',['OpenCC C API',['../group__opencc__c__api.html',1,'']]],
  ['opencc_5fclose',['opencc_close',['../group__opencc__c__api.html#gae4d995fd7bb65e2d4f386aa5cf0dbbb1',1,'opencc_close(opencc_t opencc):&#160;SimpleConverter.cpp'],['../group__opencc__c__api.html#gae4d995fd7bb65e2d4f386aa5cf0dbbb1',1,'opencc_close(opencc_t opencc):&#160;SimpleConverter.cpp']]],
  ['opencc_5fconvert_5futf8',['opencc_convert_utf8',['../group__opencc__c__api.html#gaedebe843f05973efd295461be90d50f2',1,'opencc_convert_utf8(opencc_t opencc, const char *input, size_t length):&#160;SimpleConverter.cpp'],['../group__opencc__c__api.html#gaedebe843f05973efd295461be90d50f2',1,'opencc_convert_utf8(opencc_t opencc, const char *input, size_t length):&#160;SimpleConverter.cpp']]],
  ['opencc_5fconvert_5futf8_5ffree',['opencc_convert_utf8_free',['../group__opencc__c__api.html#ga6c11f94e7bee16c080e6d8ab5c16ea84',1,'opencc_convert_utf8_free(char *str):&#160;SimpleConverter.cpp'],['../group__opencc__c__api.html#ga6c11f94e7bee16c080e6d8ab5c16ea84',1,'opencc_convert_utf8_free(char *str):&#160;SimpleConverter.cpp']]],
  ['opencc_5fconvert_5futf8_5fto_5fbuffer',['opencc_convert_utf8_to_buffer',['../group__opencc__c__api.html#ga9922ab17f25a2d93060292630eb46b81',1,'opencc_convert_utf8_to_buffer(opencc_t opencc, const char *input, size_t length, char *output):&#160;SimpleConverter.cpp'],['../group__opencc__c__api.html#ga9922ab17f25a2d93060292630eb46b81',1,'opencc_convert_utf8_to_buffer(opencc_t opencc, const char *input, size_t length, char *output):&#160;SimpleConverter.cpp']]],
  ['opencc_20c_2b_2b_20comprehensive_20api',['OpenCC C++ Comprehensive API',['../group__opencc__cpp__api.html',1,'']]],
  ['opencc_5fdefault_5fconfig_5fsimp_5fto_5ftrad',['OPENCC_DEFAULT_CONFIG_SIMP_TO_TRAD',['../group__opencc__c__api.html#ga05b32035094049395f8975f9d2ffa1a2',1,'opencc.h']]],
  ['opencc_5fdefault_5fconfig_5ftrad_5fto_5fsimp',['OPENCC_DEFAULT_CONFIG_TRAD_TO_SIMP',['../group__opencc__c__api.html#gaede2d75ff352d979e89dfc390aa855c8',1,'opencc.h']]],
  ['opencc_5ferror',['opencc_error',['../group__opencc__c__api.html#ga57698a98df649f5f3f4239419f0867bc',1,'opencc_error(void):&#160;SimpleConverter.cpp'],['../group__opencc__c__api.html#ga57698a98df649f5f3f4239419f0867bc',1,'opencc_error(void):&#160;SimpleConverter.cpp']]],
  ['opencc_5fopen',['opencc_open',['../group__opencc__c__api.html#ga3aa43bc27b880c05c14c15b2c8952336',1,'opencc_open(const char *configFileName):&#160;SimpleConverter.cpp'],['../group__opencc__c__api.html#ga3aa43bc27b880c05c14c15b2c8952336',1,'opencc_open(const char *configFileName):&#160;SimpleConverter.cpp']]],
  ['opencc_20c_2b_2b_20simple_20api',['OpenCC C++ Simple API',['../group__opencc__simple__api.html',1,'']]],
  ['opencc_5ft',['opencc_t',['../group__opencc__c__api.html#gaa08a1436fedc071dc6fc352c98a6ade9',1,'opencc.h']]],
  ['optional',['Optional',['../classopencc_1_1_optional.html',1,'opencc::Optional&lt; T &gt;'],['../classopencc_1_1_optional.html#afc26cd1d9152426778b6aa532adb10d9',1,'opencc::Optional::Optional()']]],
  ['optional_3c_20t_20_2a_20_3e',['Optional&lt; T * &gt;',['../classopencc_1_1_optional_3_01_t_01_5_01_4.html',1,'opencc']]]
];
